==> plugin-android-3.0.0-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/WebMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.ChatMessageItem;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.model.rest.Message;
import com.zoyi.channel.plugin.android.model.rest.WebPage;

/**
 * Created by jerry on 2018. 3. 28..
 */

public class WebMessageHolder extends ImageMessageHolder implements View.OnClickListener{

  RelativeLayout webPageLayout;
  TextView webTitleText;
  TextView webDescriptionText;

  private OnMessageClickListener listener;
  private Message message;

  public static WebMessageHolder newInstance(
      ViewGroup parent,
      MessageType messageType,
      OnMessageClickListener listener) {
    return new WebMessageHolder(getItemView(parent, messageType), messageType, listener);
  }

  public WebMessageHolder(View itemView, MessageType messageType, OnMessageClickListener listener) {
    super(itemView, messageType, listener);
    this.listener = listener;

    webPageLayout = itemView.findViewById(R.id.ch_message_content_webpage);
    webTitleText = itemView.findViewById(R.id.text_web_title);
    webDescriptionText = itemView.findViewById(R.id.text_web_description);
  }

  public void bind(ChatMessageItem item, boolean isConnectedMessage) {
    super.bind(item, isConnectedMessage);

    message = item.getMessage();
    if (message != null) {

      WebPage webPage = message.getWebPage();
      if (webPage != null) {
        if (MessageType.GUEST_WEB_MESSAGE == item.getType()) {
          guestMessageTextLayout.setVisibility(View.VISIBLE);
        } else {
          managerMessageTextLayout.setVisibility(View.VISIBLE);
        }
        setWebMessage(webPage, message.getMessage());
      }
    }
  }

  private void setWebMessage(WebPage webPage, String messageText) {
    webPageLayout.setVisibility(View.VISIBLE);
    webPageLayout.setOnClickListener(this);

    if (webPage.getPreviewThumb() != null) {
      super.setImageMessage(webPage.getPreviewThumb(), true, messageText);
      if (getPreviewSize() != null) {
        int width = getPreviewSize().x;

        LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(width, ViewGroup.LayoutParams.WRAP_CONTENT);
        webPageLayout.setLayoutParams(params);
      }
    }

    if (!TextUtils.isEmpty(webPage.getTitle())) {
      webTitleText.setText(webPage.getTitle());
    } else {
      webTitleText.setText(webPage.getUrl() != null ? webPage.getUrl() : "");
    }

    if (!TextUtils.isEmpty(webPage.getDescription())) {
      webDescriptionText.setText(webPage.getTitle());
    } else {
      webDescriptionText.setText(webPage.getUrl() != null ? webPage.getUrl() : "");
    }
  }

  @Override
  public void onClick(View v) {
    if (message != null) {
      listener.messageClicked(message);
    }
  }
}

==> plugin-android-3.1.2-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/WebMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.ChatMessageItem;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.model.rest.Message;
import com.zoyi.channel.plugin.android.model.rest.WebPage;
import com.zoyi.channel.plugin.android.view.layout.CHTextView;

/**
 * Created by jerry on 2018. 3. 28..
 */

public class WebMessageHolder extends ImageMessageHolder implements View.OnClickListener{

  RelativeLayout webPageLayout;
  CHTextView webTitleText;
  CHTextView webDescriptionText;

  private OnMessageClickListener listener;
  private Message message;

  public static WebMessageHolder newInstance(
      ViewGroup parent,
      MessageType messageType,
      OnMessageClickListener listener) {
    return new WebMessageHolder(getItemView(parent, messageType), messageType, listener);
  }

  public WebMessageHolder(View itemView, MessageType messageType, OnMessageClickListener listener) {
    super(itemView, messageType, listener);
    this.listener = listener;

    webPageLayout = itemView.findViewById(R.id.ch_message_content_webpage);
    webTitleText = itemView.findViewById(R.id.text_web_title);
    webDescriptionText = itemView.findViewById(R.id.text_web_description);
  }

  public void bind(ChatMessageItem item, boolean isConnectedMessage) {
    super.bind(item, isConnectedMessage);

    message = item.getMessage();
    if (message != null) {

      WebPage webPage = message.getWebPage();
      if (webPage != null) {
        if (MessageType.GUEST_WEB_MESSAGE == item.getType()) {
          guestMessageTextLayout.setVisibility(View.VISIBLE);
        } else {
          managerMessageTextLayout.setVisibility(View.VISIBLE);
        }
        setWebMessage(webPage, message.getMessage());
      }
    }
  }

  private void setWebMessage(WebPage webPage, String messageText) {
    webPageLayout.setVisibility(View.VISIBLE);
    webPageLayout.setOnClickListener(this);

    if (webPage.getPreviewThumb() != null) {
      super.setImageMessage(webPage.getPreviewThumb(), true, messageText);
      if (getPreviewSize() != null) {
        int width = getPreviewSize().x;

        LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(width, ViewGroup.LayoutParams.WRAP_CONTENT);
        webPageLayout.setLayoutParams(params);
      }
    }

    if (!TextUtils.isEmpty(webPage.getTitle())) {
      webTitleText.setText(webPage.getTitle());
    } else {
      webTitleText.setText(webPage.getUrl() != null ? webPage.getUrl() : "");
    }

    if (!TextUtils.isEmpty(webPage.getDescription())) {
      webDescriptionText.setText(webPage.getTitle());
    } else {
      webDescriptionText.setText(webPage.getUrl() != null ? webPage.getUrl() : "");
    }
  }

  @Override
  public void onClick(View v) {
    if (message != null) {
      listener.messageClicked(message);
    }
  }
}
